stl_get_census: Get Census Demographic Data

Description Usage Arguments

View source: R/get_census.R

Description

Pull demographic data from the U.S. Census Bureau's API via the tidycensus package.

Usage

1
2
stl_get_census(region, level, topic, table, variable, year, product,
  geometry = FALSE)

Arguments

region

One of "city", "city/county", "core", "ew gateway", "metro east", "metro west", or "full metro"

level

One of...

topic

For all users who wish to make common data requests.

table

For advanced users who wish to specify a full Decennial Census or American Comunity Survey table.

variable

For advanced users who wish to specify a specific Decennial Census or American Comunity Survey variable.

year

Vintage for data. For 1990, 2000, and 2010, it is possible to obtain data from the Decennial Census. For 2010-2017, it is possible to obtain data from the American Community Survey.

product

One of "census" for Decennial Census, "acs1" for the 1-year American Community Survey (ACS) estimates, "acs3" for the 3-year ACS estimates (only available 2010-2013), or "acs5" for the 5-year ACS estimates.

geometry

If TRUE, will return spatial data as an sf object; defaults to FALSE.


slu-openGIS/eads documentation built on Dec. 3, 2019, 5:32 a.m.