stl_install_keys: Install API Keys for Census and BLS APIs

Description Usage Arguments

View source: R/api_access.R

Description

Install API Keys for Census and BLS APIs

Usage

1
stl_install_keys(census, bls, overwrite = FALSE)

Arguments

census

Your Census Bureau API key, can be obtained from If you already have a tidycensus key installed, you do not need this

bls

Bureau of Labor Statistics API key, can be obtained from If you already have a blscrapeR key installed you do not need this

overwrite

Logical, if TRUE will overwrite the installation in the .Renviron of the keys specified


slu-openGIS/eads documentation built on Dec. 3, 2019, 5:32 a.m.