Pull demographic data from the U.S. Census Bureau's API via the
tidycensus package.
1 2 | stl_get_census(region, level, topic, table, variable, year, product,
geometry = FALSE)
|
region |
One of |
level |
One of... |
topic |
For all users who wish to make common data requests. |
table |
For advanced users who wish to specify a full Decennial Census or American Comunity Survey table. |
variable |
For advanced users who wish to specify a specific Decennial Census or American Comunity Survey variable. |
year |
Vintage for data. For 1990, 2000, and 2010, it is possible to obtain data from the Decennial Census. For 2010-2017, it is possible to obtain data from the American Community Survey. |
product |
One of |
geometry |
If |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.