Description Usage Arguments
View source: R/api_access.R
Install API Keys for Census and BLS APIs
1
stl_install_keys(census, bls, overwrite = FALSE)
census
Your Census Bureau API key, can be obtained from If you already have a tidycensus key installed, you do not need this
tidycensus
bls
Bureau of Labor Statistics API key, can be obtained from If you already have a blscrapeR key installed you do not need this
blscrapeR
overwrite
Logical, if TRUE will overwrite the installation in the .Renviron of the keys specified
Add the following code to your website.
REMOVE THIS Copy to clipboard
For more information on customizing the embed code, read Embedding Snippets.